# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureform/proto/serving.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x66\x65\x61tureform/proto/serving.proto\x12\x19\x66\x65\x61tureform.serving.proto\"\x15\n\x05Model\x12\x0c\n\x04name\x18\x01 \x01(\t\"}\n\x13TrainingDataRequest\x12\x35\n\x02id\x18\x01 \x01(\x0b\x32).featureform.serving.proto.TrainingDataID\x12/\n\x05model\x18\x02 \x01(\x0b\x32 .featureform.serving.proto.Model\"/\n\x0eTrainingDataID\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"L\n\x10TrainingDataRows\x12\x38\n\x04rows\x18\x01 \x03(\x0b\x32*.featureform.serving.proto.TrainingDataRow\"v\n\x0fTrainingDataRow\x12\x32\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32 .featureform.serving.proto.Value\x12/\n\x05label\x18\x02 \x01(\x0b\x32 .featureform.serving.proto.Value\"\xb3\x01\n\x13\x46\x65\x61tureServeRequest\x12\x36\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32$.featureform.serving.proto.FeatureID\x12\x33\n\x08\x65ntities\x18\x02 \x03(\x0b\x32!.featureform.serving.proto.Entity\x12/\n\x05model\x18\x03 \x01(\x0b\x32 .featureform.serving.proto.Model\"}\n\nFeatureRow\x12\x34\n\x06values\x18\x01 \x03(\x0b\x32 .featureform.serving.proto.ValueB\x02\x18\x01\x12\x39\n\x0bvalue_lists\x18\x02 \x03(\x0b\x32$.featureform.serving.proto.ValueList\"=\n\tValueList\x12\x30\n\x06values\x18\x01 \x03(\x0b\x32 .featureform.serving.proto.Value\"R\n\x18\x42\x61tchFeatureServeRequest\x12\x36\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32$.featureform.serving.proto.FeatureID\"L\n\x10\x42\x61tchFeatureRows\x12\x38\n\x04rows\x18\x01 \x03(\x0b\x32*.featureform.serving.proto.BatchFeatureRow\"w\n\x0f\x42\x61tchFeatureRow\x12\x30\n\x06\x65ntity\x18\x01 \x01(\x0b\x32 .featureform.serving.proto.Value\x12\x32\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32 .featureform.serving.proto.Value\"*\n\tFeatureID\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"9\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x05value\x18\x02 \x01(\tB\x02\x18\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xba\x02\n\x05Value\x12\x13\n\tstr_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x05H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x15\n\x0bint64_value\x18\x05 \x01(\x03H\x00\x12\x15\n\x0bint32_value\x18\x06 \x01(\x05H\x00\x12\x14\n\nbool_value\x18\x07 \x01(\x08H\x00\x12\x1c\n\x12on_demand_function\x18\x08 \x01(\x0cH\x00\x12=\n\x0evector32_value\x18\t \x01(\x0b\x32#.featureform.serving.proto.Vector32H\x00\x12\x16\n\x0cuint32_value\x18\n \x01(\rH\x00\x12\x16\n\x0cuint64_value\x18\x0b \x01(\x04H\x00\x42\x07\n\x05value\")\n\x08SourceID\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"S\n\x11SourceDataRequest\x12/\n\x02id\x18\x01 \x01(\x0b\x32#.featureform.serving.proto.SourceID\x12\r\n\x05limit\x18\x02 \x01(\x03\"F\n\x13SourceColumnRequest\x12/\n\x02id\x18\x01 \x01(\x0b\x32#.featureform.serving.proto.SourceID\"H\n\x0eSourceDataRows\x12\x36\n\x04rows\x18\x01 \x03(\x0b\x32(.featureform.serving.proto.SourceDataRow\"?\n\rSourceDataRow\x12.\n\x04rows\x18\x01 \x03(\x0b\x32 .featureform.serving.proto.Value\"$\n\x11SourceDataColumns\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\"S\n\x1aTrainingDataColumnsRequest\x12\x35\n\x02id\x18\x01 \x01(\x0b\x32).featureform.serving.proto.TrainingDataID\"2\n\x0fTrainingColumns\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x03(\t\x12\r\n\x05label\x18\x02 \x01(\t\"\x19\n\x08Vector32\x12\r\n\x05value\x18\x01 \x03(\x02\"\x82\x01\n\x0eNearestRequest\x12\x30\n\x02id\x18\x01 \x01(\x0b\x32$.featureform.serving.proto.FeatureID\x12\x33\n\x06vector\x18\x02 \x01(\x0b\x32#.featureform.serving.proto.Vector32\x12\t\n\x01k\x18\x03 \x01(\x05\"#\n\x0fNearestResponse\x12\x10\n\x08\x65ntities\x18\x01 \x03(\t\"@\n\x11ResourceIdRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"$\n\x10ResourceLocation\x12\x10\n\x08location\x18\x01 \x01(\t\"\x9f\x02\n\x15TrainTestSplitRequest\x12\x35\n\x02id\x18\x01 \x01(\x0b\x32).featureform.serving.proto.TrainingDataID\x12/\n\x05model\x18\x02 \x01(\x0b\x32 .featureform.serving.proto.Model\x12\x11\n\ttest_size\x18\x03 \x01(\x02\x12\x12\n\ntrain_size\x18\x04 \x01(\x02\x12\x0f\n\x07shuffle\x18\x05 \x01(\x08\x12\x14\n\x0crandom_state\x18\x06 \x01(\x05\x12<\n\x0crequest_type\x18\x07 \x01(\x0e\x32&.featureform.serving.proto.RequestType\x12\x12\n\nbatch_size\x18\x08 \x01(\x05\"\xd0\x01\n\x1b\x42\x61tchTrainTestSplitResponse\x12<\n\x0crequest_type\x18\x01 \x01(\x0e\x32&.featureform.serving.proto.RequestType\x12\x15\n\riterator_done\x18\x02 \x01(\x08\x12\x15\n\x0binitialized\x18\x03 \x01(\x08H\x00\x12;\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32+.featureform.serving.proto.TrainingDataRowsH\x00\x42\x08\n\x06result\"\x7f\n\x17\x46\x65\x61tureViewServeRequest\x12\x11\n\tview_name\x18\x01 \x01(\t\x12\x12\n\nentity_ids\x18\x02 \x03(\t\x12=\n\x0f\x66ilter_features\x18\x03 \x03(\x0b\x32$.featureform.serving.proto.FeatureID\"A\n\rFeatureColumn\x12\x16\n\x0e\x66\x65\x61ture_column\x18\x01 \x01(\t\x12\x18\n\x10timestamp_column\x18\x02 \x01(\t\"m\n\x11\x46\x65\x61tureViewSchema\x12\x15\n\rentity_column\x18\x01 \x01(\t\x12\x41\n\x0f\x66\x65\x61ture_columns\x18\x02 \x03(\x0b\x32(.featureform.serving.proto.FeatureColumn\"\x8a\x01\n\x0f\x46\x65\x61tureViewRows\x12<\n\x06schema\x18\x01 \x01(\x0b\x32,.featureform.serving.proto.FeatureViewSchema\x12\x39\n\x0bvalue_lists\x18\x02 \x03(\x0b\x32$.featureform.serving.proto.ValueList*5\n\x0bRequestType\x12\x0e\n\nINITIALIZE\x10\x00\x12\x0c\n\x08TRAINING\x10\x01\x12\x08\n\x04TEST\x10\x02\x32\x87\t\n\x07\x46\x65\x61ture\x12o\n\x0cTrainingData\x12..featureform.serving.proto.TrainingDataRequest\x1a+.featureform.serving.proto.TrainingDataRows\"\x00\x30\x01\x12\x80\x01\n\x0eTrainTestSplit\x12\x30.featureform.serving.proto.TrainTestSplitRequest\x1a\x36.featureform.serving.proto.BatchTrainTestSplitResponse\"\x00(\x01\x30\x01\x12z\n\x13TrainingDataColumns\x12\x35.featureform.serving.proto.TrainingDataColumnsRequest\x1a*.featureform.serving.proto.TrainingColumns\"\x00\x12g\n\x0c\x46\x65\x61tureServe\x12..featureform.serving.proto.FeatureServeRequest\x1a%.featureform.serving.proto.FeatureRow\"\x00\x12i\n\nSourceData\x12,.featureform.serving.proto.SourceDataRequest\x1a).featureform.serving.proto.SourceDataRows\"\x00\x30\x01\x12o\n\rSourceColumns\x12..featureform.serving.proto.SourceColumnRequest\x1a,.featureform.serving.proto.SourceDataColumns\"\x00\x12\x62\n\x07Nearest\x12).featureform.serving.proto.NearestRequest\x1a*.featureform.serving.proto.NearestResponse\"\x00\x12y\n\x11\x42\x61tchFeatureServe\x12\x33.featureform.serving.proto.BatchFeatureServeRequest\x1a+.featureform.serving.proto.BatchFeatureRows\"\x00\x30\x01\x12r\n\x13GetResourceLocation\x12,.featureform.serving.proto.ResourceIdRequest\x1a+.featureform.serving.proto.ResourceLocation\"\x00\x12t\n\x10ServeFeatureView\x12\x32.featureform.serving.proto.FeatureViewServeRequest\x1a*.featureform.serving.proto.FeatureViewRows\"\x00\x42\x1eZ\x1cgithub.com/featureform/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureform.proto.serving_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034github.com/featureform/proto'
  _globals['_FEATUREROW'].fields_by_name['values']._options = None
  _globals['_FEATUREROW'].fields_by_name['values']._serialized_options = b'\030\001'
  _globals['_ENTITY'].fields_by_name['value']._options = None
  _globals['_ENTITY'].fields_by_name['value']._serialized_options = b'\030\001'
  _globals['_REQUESTTYPE']._serialized_start=3298
  _globals['_REQUESTTYPE']._serialized_end=3351
  _globals['_MODEL']._serialized_start=62
  _globals['_MODEL']._serialized_end=83
  _globals['_TRAININGDATAREQUEST']._serialized_start=85
  _globals['_TRAININGDATAREQUEST']._serialized_end=210
  _globals['_TRAININGDATAID']._serialized_start=212
  _globals['_TRAININGDATAID']._serialized_end=259
  _globals['_TRAININGDATAROWS']._serialized_start=261
  _globals['_TRAININGDATAROWS']._serialized_end=337
  _globals['_TRAININGDATAROW']._serialized_start=339
  _globals['_TRAININGDATAROW']._serialized_end=457
  _globals['_FEATURESERVEREQUEST']._serialized_start=460
  _globals['_FEATURESERVEREQUEST']._serialized_end=639
  _globals['_FEATUREROW']._serialized_start=641
  _globals['_FEATUREROW']._serialized_end=766
  _globals['_VALUELIST']._serialized_start=768
  _globals['_VALUELIST']._serialized_end=829
  _globals['_BATCHFEATURESERVEREQUEST']._serialized_start=831
  _globals['_BATCHFEATURESERVEREQUEST']._serialized_end=913
  _globals['_BATCHFEATUREROWS']._serialized_start=915
  _globals['_BATCHFEATUREROWS']._serialized_end=991
  _globals['_BATCHFEATUREROW']._serialized_start=993
  _globals['_BATCHFEATUREROW']._serialized_end=1112
  _globals['_FEATUREID']._serialized_start=1114
  _globals['_FEATUREID']._serialized_end=1156
  _globals['_ENTITY']._serialized_start=1158
  _globals['_ENTITY']._serialized_end=1215
  _globals['_VALUE']._serialized_start=1218
  _globals['_VALUE']._serialized_end=1532
  _globals['_SOURCEID']._serialized_start=1534
  _globals['_SOURCEID']._serialized_end=1575
  _globals['_SOURCEDATAREQUEST']._serialized_start=1577
  _globals['_SOURCEDATAREQUEST']._serialized_end=1660
  _globals['_SOURCECOLUMNREQUEST']._serialized_start=1662
  _globals['_SOURCECOLUMNREQUEST']._serialized_end=1732
  _globals['_SOURCEDATAROWS']._serialized_start=1734
  _globals['_SOURCEDATAROWS']._serialized_end=1806
  _globals['_SOURCEDATAROW']._serialized_start=1808
  _globals['_SOURCEDATAROW']._serialized_end=1871
  _globals['_SOURCEDATACOLUMNS']._serialized_start=1873
  _globals['_SOURCEDATACOLUMNS']._serialized_end=1909
  _globals['_TRAININGDATACOLUMNSREQUEST']._serialized_start=1911
  _globals['_TRAININGDATACOLUMNSREQUEST']._serialized_end=1994
  _globals['_TRAININGCOLUMNS']._serialized_start=1996
  _globals['_TRAININGCOLUMNS']._serialized_end=2046
  _globals['_VECTOR32']._serialized_start=2048
  _globals['_VECTOR32']._serialized_end=2073
  _globals['_NEARESTREQUEST']._serialized_start=2076
  _globals['_NEARESTREQUEST']._serialized_end=2206
  _globals['_NEARESTRESPONSE']._serialized_start=2208
  _globals['_NEARESTRESPONSE']._serialized_end=2243
  _globals['_RESOURCEIDREQUEST']._serialized_start=2245
  _globals['_RESOURCEIDREQUEST']._serialized_end=2309
  _globals['_RESOURCELOCATION']._serialized_start=2311
  _globals['_RESOURCELOCATION']._serialized_end=2347
  _globals['_TRAINTESTSPLITREQUEST']._serialized_start=2350
  _globals['_TRAINTESTSPLITREQUEST']._serialized_end=2637
  _globals['_BATCHTRAINTESTSPLITRESPONSE']._serialized_start=2640
  _globals['_BATCHTRAINTESTSPLITRESPONSE']._serialized_end=2848
  _globals['_FEATUREVIEWSERVEREQUEST']._serialized_start=2850
  _globals['_FEATUREVIEWSERVEREQUEST']._serialized_end=2977
  _globals['_FEATURECOLUMN']._serialized_start=2979
  _globals['_FEATURECOLUMN']._serialized_end=3044
  _globals['_FEATUREVIEWSCHEMA']._serialized_start=3046
  _globals['_FEATUREVIEWSCHEMA']._serialized_end=3155
  _globals['_FEATUREVIEWROWS']._serialized_start=3158
  _globals['_FEATUREVIEWROWS']._serialized_end=3296
  _globals['_FEATURE']._serialized_start=3354
  _globals['_FEATURE']._serialized_end=4513
# @@protoc_insertion_point(module_scope)
