# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: featureform/proto/metadata.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n featureform/proto/metadata.proto\x12\"featureform.serving.metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19google/protobuf/any.proto\"k\n\x0eOktaAuthConfig\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x1f\n\x17\x61uthorization_server_id\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\t\x12\x15\n\rapi_client_id\x18\x04 \x01(\t\"\x17\n\x15PassThroughAuthConfig\"\x10\n\x0e\x43IDRAuthConfig\"\xf1\x01\n\nAuthConfig\x12\x42\n\x04okta\x18\x01 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.OktaAuthConfigH\x00\x12Q\n\x0cpass_through\x18\x02 \x01(\x0b\x32\x39.featureform.serving.metadata.proto.PassThroughAuthConfigH\x00\x12\x42\n\x04\x63idr\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.CIDRAuthConfigH\x00\x42\x08\n\x06\x63onfig\"\x14\n\x04Name\x12\x0c\n\x04name\x18\x01 \x01(\t\"Y\n\x0bNameRequest\x12\x36\n\x04name\x18\x01 \x01(\x0b\x32(.featureform.serving.metadata.proto.Name\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"S\n\x0b\x45rrorStatus\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12%\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\"\x9f\x02\n\x0eResourceStatus\x12I\n\x06status\x18\x01 \x01(\x0e\x32\x39.featureform.serving.metadata.proto.ResourceStatus.Status\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x45\n\x0c\x65rror_status\x18\x03 \x01(\x0b\x32/.featureform.serving.metadata.proto.ErrorStatus\"d\n\x06Status\x12\r\n\tNO_STATUS\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\t\n\x05READY\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tCANCELLED\x10\x06\"\x98\x01\n\nResourceID\x12\x41\n\x08resource\x18\x01 \x01(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12G\n\rresource_type\x18\x02 \x01(\x0e\x32\x30.featureform.serving.metadata.proto.ResourceType\"\x9b\x01\n\x10SetStatusRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\"n\n\x15ScheduleChangeRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\x12\x10\n\x08schedule\x18\x02 \x01(\t\",\n\x0bNameVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\"o\n\x12NameVariantRequest\x12\x45\n\x0cname_variant\x18\x01 \x01(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x07\n\x05\x45mpty\"!\n\x0bListRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"\x86\x01\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x17\n\x0f\x64\x65\x66\x61ult_variant\x18\x03 \x01(\t\x12\x10\n\x08variants\x18\x04 \x03(\t\"4\n\x07\x43olumns\x12\x0e\n\x06\x65ntity\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\t\"\x1f\n\x0ePythonFunction\x12\r\n\x05query\x18\x01 \x01(\x0c\"\"\n\x06Stream\x12\x18\n\x10offline_provider\x18\x01 \x01(\t\"\xa5\x03\n\x0fResourceVariant\x12M\n\x0f\x66\x65\x61ture_variant\x18\x01 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FeatureVariantH\x00\x12I\n\rlabel_variant\x18\x02 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.LabelVariantH\x00\x12V\n\x14training_set_variant\x18\x03 \x01(\x0b\x32\x36.featureform.serving.metadata.proto.TrainingSetVariantH\x00\x12K\n\x0esource_variant\x18\x04 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.SourceVariantH\x00\x12G\n\x0c\x66\x65\x61ture_view\x18\x05 \x01(\x0b\x32/.featureform.serving.metadata.proto.FeatureViewH\x00\x42\n\n\x08resource\"p\n\x14GetEquivalentRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x44\n\x07variant\x18\x02 \x01(\x0b\x32\x33.featureform.serving.metadata.proto.ResourceVariant\"g\n\nRunRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x45\n\x08variants\x18\x02 \x03(\x0b\x32\x33.featureform.serving.metadata.proto.ResourceVariant\"\xb0\n\n\x0e\x46\x65\x61tureVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12?\n\x06source\x18\x03 \x01(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x0e\n\x06\x65ntity\x18\x05 \x01(\t\x12+\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x42\n\x06status\x18\n \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x45\n\x0ctrainingsets\x18\x0b \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12>\n\x07\x63olumns\x18\x0c \x01(\x0b\x32+.featureform.serving.metadata.proto.ColumnsH\x00\x12\x46\n\x08\x66unction\x18\x11 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.PythonFunctionH\x00\x12<\n\x06stream\x18\x15 \x01(\x0b\x32*.featureform.serving.metadata.proto.StreamH\x00\x12\x30\n\x0clast_updated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08schedule\x18\x0e \x01(\t\x12\x36\n\x04tags\x18\x0f \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x10 \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x41\n\x04mode\x18\x12 \x01(\x0e\x32\x33.featureform.serving.metadata.proto.ComputationMode\x12\x13\n\x07task_id\x18\x17 \x01(\tB\x02\x18\x01\x12\x14\n\x0ctask_id_list\x18\x18 \x03(\t\x12T\n\x15\x61\x64\x64itional_parameters\x18\x16 \x01(\x0b\x32\x35.featureform.serving.metadata.proto.FeatureParameters\x12;\n\x04type\x18\x19 \x01(\x0b\x32-.featureform.serving.metadata.proto.ValueType\x12^\n\x19resource_snowflake_config\x18\x1a \x01(\x0b\x32;.featureform.serving.metadata.proto.ResourceSnowflakeConfig\x12\x16\n\nis_deleted\x18\x1b \x01(\x08\x42\x02\x18\x01\x12/\n\x07\x64\x65leted\x18\x1c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12\x1e\n\x16offline_store_provider\x18\x1d \x01(\t\x12M\n\x17offline_store_locations\x18\x1e \x03(\x0b\x32,.featureform.serving.metadata.proto.Location\x12\x15\n\rfeature_views\x18\x1f \x03(\tB\n\n\x08location\"x\n\x15\x46\x65\x61tureVariantRequest\x12K\n\x0f\x66\x65\x61ture_variant\x18\x01 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FeatureVariant\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x97\x01\n\tValueType\x12@\n\x06scalar\x18\x01 \x01(\x0e\x32..featureform.serving.metadata.proto.ScalarTypeH\x00\x12@\n\x06vector\x18\x02 \x01(\x0b\x32..featureform.serving.metadata.proto.VectorTypeH\x00\x42\x06\n\x04Type\"u\n\nVectorType\x12>\n\x06scalar\x18\x01 \x01(\x0e\x32..featureform.serving.metadata.proto.ScalarType\x12\x11\n\tdimension\x18\x02 \x01(\x05\x12\x14\n\x0cis_embedding\x18\x03 \x01(\x08\"\xcf\x01\n\x11\x46\x65\x61tureParameters\x12W\n\x0bprecomputed\x18\x01 \x01(\x0b\x32@.featureform.serving.metadata.proto.PrecomputedFeatureParametersH\x00\x12Q\n\x08ondemand\x18\x02 \x01(\x0b\x32=.featureform.serving.metadata.proto.OndemandFeatureParametersH\x00\x42\x0e\n\x0c\x66\x65\x61ture_type\"\x1e\n\x1cPrecomputedFeatureParameters\"/\n\x19OndemandFeatureParameters\x12\x12\n\ndefinition\x18\x01 \x01(\t\"d\n\nFeatureLag\x12\x0f\n\x07\x66\x65\x61ture\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12&\n\x03lag\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x84\x01\n\x05Label\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x17\n\x0f\x64\x65\x66\x61ult_variant\x18\x03 \x01(\t\x12\x10\n\x08variants\x18\x04 \x03(\t\"\xd2\x07\n\x0cLabelVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12?\n\x06source\x18\x05 \x01(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x0e\n\x06\x65ntity\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05owner\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x42\n\x06status\x18\n \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x45\n\x0ctrainingsets\x18\x0b \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12>\n\x07\x63olumns\x18\x0c \x01(\x0b\x32+.featureform.serving.metadata.proto.ColumnsH\x00\x12<\n\x06stream\x18\x10 \x01(\x0b\x32*.featureform.serving.metadata.proto.StreamH\x00\x12M\n\x0f\x65ntity_mappings\x18\x16 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.EntityMappingsH\x00\x12\x36\n\x04tags\x18\r \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x0e \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x13\n\x07task_id\x18\x0f \x01(\tB\x02\x18\x01\x12;\n\x04type\x18\x12 \x01(\x0b\x32-.featureform.serving.metadata.proto.ValueType\x12\x14\n\x0ctask_id_list\x18\x11 \x03(\t\x12^\n\x19resource_snowflake_config\x18\x13 \x01(\x0b\x32;.featureform.serving.metadata.proto.ResourceSnowflakeConfig\x12\x16\n\nis_deleted\x18\x14 \x01(\x08\x42\x02\x18\x01\x12/\n\x07\x64\x65leted\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x42\n\n\x08location\"\x85\x01\n\x0e\x45ntityMappings\x12\x43\n\x08mappings\x18\x01 \x03(\x0b\x32\x31.featureform.serving.metadata.proto.EntityMapping\x12\x14\n\x0cvalue_column\x18\x02 \x01(\t\x12\x18\n\x10timestamp_column\x18\x03 \x01(\t\"4\n\rEntityMapping\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rentity_column\x18\x02 \x01(\t\"r\n\x13LabelVariantRequest\x12G\n\rlabel_variant\x18\x01 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.LabelVariant\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x8c\x05\n\x08Provider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x10\n\x08software\x18\x04 \x01(\t\x12\x0c\n\x04team\x18\x05 \x01(\t\x12\x19\n\x11serialized_config\x18\x06 \x01(\x0c\x12\x42\n\x06status\x18\x07 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12@\n\x07sources\x18\x08 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x41\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x45\n\x0ctrainingsets\x18\n \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12?\n\x06labels\x18\x0b \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x36\n\x04tags\x18\x0c \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\r \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x16\n\nis_deleted\x18\x0e \x01(\x08\x42\x02\x18\x01\x12/\n\x07\x64\x65leted\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\"e\n\x0fProviderRequest\x12>\n\x08provider\x18\x01 \x01(\x0b\x32,.featureform.serving.metadata.proto.Provider\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x8a\x01\n\x0bTrainingSet\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x17\n\x0f\x64\x65\x66\x61ult_variant\x18\x03 \x01(\t\x12\x10\n\x08variants\x18\x04 \x03(\t\"\xfa\x06\n\x12TrainingSetVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x42\n\x06status\x18\x07 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x41\n\x08\x66\x65\x61tures\x18\x08 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12>\n\x05label\x18\t \x01(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x30\n\x0clast_updated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08schedule\x18\x0e \x01(\t\x12\x44\n\x0c\x66\x65\x61ture_lags\x18\x0f \x03(\x0b\x32..featureform.serving.metadata.proto.FeatureLag\x12\x36\n\x04tags\x18\x10 \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x11 \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x13\n\x07task_id\x18\x12 \x01(\tB\x02\x18\x01\x12\x14\n\x0ctask_id_list\x18\x13 \x03(\t\x12^\n\x19resource_snowflake_config\x18\x14 \x01(\x0b\x32;.featureform.serving.metadata.proto.ResourceSnowflakeConfig\x12\x16\n\nis_deleted\x18\x15 \x01(\x08\x42\x02\x18\x01\x12/\n\x07\x64\x65leted\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12\x41\n\x04type\x18\x17 \x01(\x0e\x32\x33.featureform.serving.metadata.proto.TrainingSetType\"\x85\x01\n\x19TrainingSetVariantRequest\x12T\n\x14training_set_variant\x18\x01 \x01(\x0b\x32\x36.featureform.serving.metadata.proto.TrainingSetVariant\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\xcd\x03\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x41\n\x08\x66\x65\x61tures\x18\x04 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12?\n\x06labels\x18\x05 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x45\n\x0ctrainingsets\x18\x06 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x36\n\x04tags\x18\x07 \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x08 \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x15\n\rfeature_views\x18\t \x03(\t\"_\n\rEntityRequest\x12:\n\x06\x65ntity\x18\x01 \x01(\x0b\x32*.featureform.serving.metadata.proto.Entity\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\xf1\x02\n\x05Model\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12?\n\x06labels\x18\x04 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x45\n\x0ctrainingsets\x18\x05 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x36\n\x04tags\x18\x06 \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x07 \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\"\\\n\x0cModelRequest\x12\x38\n\x05model\x18\x01 \x01(\x0b\x32).featureform.serving.metadata.proto.Model\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x8c\x02\n\rStreamChannel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\r\n\x05owner\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_updated\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"u\n\x14StreamChannelRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12I\n\x0estream_channel\x18\x02 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.StreamChannel\"\xf8\x03\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x41\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12?\n\x06labels\x18\x04 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x45\n\x0ctrainingsets\x18\x05 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12@\n\x07sources\x18\x06 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x36\n\x04tags\x18\x08 \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\t \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x15\n\rfeature_views\x18\n \x03(\t\"Y\n\x0bUserRequest\x12\x36\n\x04user\x18\x01 \x01(\x0b\x32(.featureform.serving.metadata.proto.User\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"\x85\x01\n\x06Source\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x42\n\x06status\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x17\n\x0f\x64\x65\x66\x61ult_variant\x18\x03 \x01(\t\x12\x10\n\x08variants\x18\x04 \x03(\t\"\xbc\x07\n\rSourceVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12L\n\x0etransformation\x18\x0e \x01(\x0b\x32\x32.featureform.serving.metadata.proto.TransformationH\x00\x12\x46\n\x0bprimaryData\x18\x0f \x01(\x0b\x32/.featureform.serving.metadata.proto.PrimaryDataH\x00\x12\r\n\x05owner\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x06status\x18\x08 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\r\n\x05table\x18\t \x01(\t\x12\x45\n\x0ctrainingsets\x18\n \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x41\n\x08\x66\x65\x61tures\x18\x0b \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12?\n\x06labels\x18\x0c \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x30\n\x0clast_updated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08schedule\x18\x10 \x01(\t\x12\x36\n\x04tags\x18\x11 \x01(\x0b\x32(.featureform.serving.metadata.proto.Tags\x12\x42\n\nproperties\x18\x12 \x01(\x0b\x32..featureform.serving.metadata.proto.Properties\x12\x13\n\x07task_id\x18\x13 \x01(\tB\x02\x18\x01\x12\x33\n\x10max_job_duration\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x14\n\x0ctask_id_list\x18\x15 \x03(\t\x12\x16\n\nis_deleted\x18\x16 \x01(\x08\x42\x02\x18\x01\x12/\n\x07\x64\x65leted\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x42\x0c\n\ndefinition\"u\n\x14SourceVariantRequest\x12I\n\x0esource_variant\x18\x01 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.SourceVariant\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"(\n\nSparkParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\x0bWriteOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"+\n\rTableProperty\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe7\x01\n\nSparkFlags\x12\x44\n\x0cspark_params\x18\x01 \x03(\x0b\x32..featureform.serving.metadata.proto.SparkParam\x12\x46\n\rwrite_options\x18\x02 \x03(\x0b\x32/.featureform.serving.metadata.proto.WriteOption\x12K\n\x10table_properties\x18\x03 \x03(\x0b\x32\x31.featureform.serving.metadata.proto.TableProperty\"\xb6\x03\n\x08Location\x12=\n\x05table\x18\x01 \x01(\x0b\x32,.featureform.serving.metadata.proto.SQLTableH\x00\x12G\n\tfilestore\x18\x02 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FileStoreTableH\x00\x12\x43\n\x07\x63\x61talog\x18\x03 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.CatalogTableH\x00\x12>\n\x05kafka\x18\x04 \x01(\x0b\x32).featureform.serving.metadata.proto.KafkaB\x02\x18\x01H\x00\x12\x44\n\x06online\x18\x05 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.OnlineLocationH\x00\x12K\n\x0estream_channel\x18\x06 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.StreamChannelH\x00\x42\n\n\x08location\"\xe7\x06\n\x0eTransformation\x12R\n\x11SQLTransformation\x18\x01 \x01(\x0b\x32\x35.featureform.serving.metadata.proto.SQLTransformationH\x00\x12P\n\x10\x44\x46Transformation\x18\x02 \x01(\x0b\x32\x34.featureform.serving.metadata.proto.DFTransformationH\x00\x12M\n\x0fkubernetes_args\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.KubernetesArgsH\x01\x12J\n\rHashPartition\x18\x04 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.HashPartitionH\x02\x12L\n\x0e\x44\x61ilyPartition\x18\x05 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.DailyPartitionH\x02\x12\x43\n\x0bspark_flags\x18\x06 \x01(\x0b\x32..featureform.serving.metadata.proto.SparkFlags\x12=\n\x05table\x18\x07 \x01(\x0b\x32,.featureform.serving.metadata.proto.SQLTableH\x03\x12G\n\tfilestore\x18\x08 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FileStoreTableH\x03\x12\x43\n\x07\x63\x61talog\x18\t \x01(\x0b\x32\x30.featureform.serving.metadata.proto.CatalogTableH\x03\x12>\n\x05kafka\x18\n \x01(\x0b\x32).featureform.serving.metadata.proto.KafkaB\x02\x18\x01H\x03\x12K\n\x0estream_channel\x18\x0b \x01(\x0b\x32\x31.featureform.serving.metadata.proto.StreamChannelH\x03\x42\x06\n\x04typeB\x06\n\x04\x61rgsB\x0b\n\tpartitionB\n\n\x08location\"0\n\rHashPartition\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\x12\x0f\n\x07\x62uckets\x18\x02 \x01(\x05\" \n\x0e\x44\x61ilyPartition\x12\x0e\n\x06\x63olumn\x18\x01 \x01(\t\"o\n\x17KubernetesResourceSpecs\x12\x13\n\x0b\x63pu_request\x18\x01 \x01(\t\x12\x11\n\tcpu_limit\x18\x02 \x01(\t\x12\x16\n\x0ememory_request\x18\x03 \x01(\t\x12\x14\n\x0cmemory_limit\x18\x04 \x01(\t\"r\n\x0eKubernetesArgs\x12\x14\n\x0c\x64ocker_image\x18\x01 \x01(\t\x12J\n\x05specs\x18\x02 \x01(\x0b\x32;.featureform.serving.metadata.proto.KubernetesResourceSpecs\"\x8a\x03\n\x11SQLTransformation\x12\r\n\x05query\x18\x01 \x01(\t\x12?\n\x06source\x18\x02 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x16\n\x0eis_incremental\x18\x03 \x01(\x08\x12K\n\x12incremental_source\x18\x04 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12^\n\x19resource_snowflake_config\x18\x05 \x01(\x0b\x32;.featureform.serving.metadata.proto.ResourceSnowflakeConfig\x12\x14\n\x0cis_streaming\x18\x06 \x01(\x08\x12J\n\x11streaming_sources\x18\x07 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\"\xd9\x02\n\x10\x44\x46Transformation\x12\r\n\x05query\x18\x01 \x01(\x0c\x12?\n\x06inputs\x18\x02 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x13\n\x0bsource_text\x18\x03 \x01(\t\x12\x16\n\x0eis_incremental\x18\x04 \x01(\x08\x12L\n\x13incremental_sources\x18\x05 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x14\n\x0cis_streaming\x18\x06 \x01(\x08\x12G\n\x0estream_sources\x18\x07 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x1b\n\x13\x63\x61nonical_func_text\x18\x08 \x01(\t\"\x8d\x03\n\x0bPrimaryData\x12=\n\x05table\x18\x01 \x01(\x0b\x32,.featureform.serving.metadata.proto.SQLTableH\x00\x12G\n\tfilestore\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FileStoreTableH\x00\x12\x43\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.CatalogTableH\x00\x12>\n\x05kafka\x18\x05 \x01(\x0b\x32).featureform.serving.metadata.proto.KafkaB\x02\x18\x01H\x00\x12K\n\x0estream_channel\x18\x06 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.StreamChannelH\x00\x12\x18\n\x10timestamp_column\x18\x02 \x01(\tB\n\n\x08location\":\n\x08SQLTable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"\x1e\n\x0e\x46ileStoreTable\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x16\n\x05Kafka\x12\r\n\x05topic\x18\x01 \x01(\t\"\x9c\x01\n\x0c\x43\x61talogTable\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12\x14\n\x0ctable_format\x18\x03 \x01(\t\x12\x0e\n\x06schema\x18\x04 \x01(\t\x12\x45\n\x0c\x63\x61talog_type\x18\x05 \x01(\x0e\x32/.featureform.serving.metadata.proto.CatalogType\"\x13\n\x04Tags\x12\x0b\n\x03tag\x18\x01 \x03(\t\"+\n\x08Property\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\xbb\x01\n\nProperties\x12N\n\x08property\x18\x01 \x03(\x0b\x32<.featureform.serving.metadata.proto.Properties.PropertyEntry\x1a]\n\rPropertyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.featureform.serving.metadata.proto.Property:\x02\x38\x01\"\x7f\n\x17StreamingFeatureVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x12&\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"}\n\x15StreamingLabelVariant\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07variant\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x04 \x01(\t\x12&\n\x02ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x01\n\x17ResourceSnowflakeConfig\x12]\n\x14\x64ynamic_table_config\x18\x01 \x01(\x0b\x32?.featureform.serving.metadata.proto.SnowflakeDynamicTableConfig\x12\x11\n\twarehouse\x18\x02 \x01(\t\"\xbc\x01\n\x1bSnowflakeDynamicTableConfig\x12\x12\n\ntarget_lag\x18\x01 \x01(\t\x12\x45\n\x0crefresh_mode\x18\x02 \x01(\x0e\x32/.featureform.serving.metadata.proto.RefreshMode\x12\x42\n\ninitialize\x18\x03 \x01(\x0e\x32..featureform.serving.metadata.proto.Initialize\"]\n\x16MarkForDeletionRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\"\x19\n\x17MarkForDeletionResponse\"^\n\x17\x46inalizeDeletionRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\"\x1a\n\x18\x46inalizeDeletionResponse\"j\n#GetStagedForDeletionResourceRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\"u\n$GetStagedForDeletionResourceResponse\x12M\n\x10resource_variant\x18\x01 \x01(\x0b\x32\x33.featureform.serving.metadata.proto.ResourceVariant\"[\n\x14PruneResourceRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\"\xb6\x01\n\x15PruneResourceResponse\x12\x12\n\ntarget_lag\x18\x01 \x01(\t\x12\x45\n\x0crefresh_mode\x18\x02 \x01(\x0e\x32/.featureform.serving.metadata.proto.RefreshMode\x12\x42\n\ninitialize\x18\x03 \x01(\x0e\x32..featureform.serving.metadata.proto.Initialize\"\xc6\x01\n GetDownstreamDependenciesRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\x12I\n\x0f\x64\x65pendency_type\x18\x02 \x01(\x0e\x32\x30.featureform.serving.metadata.proto.ResourceType\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"\xb7\x05\n!GetDownstreamDependenciesResponse\x12M\n\x0f\x66\x65\x61ture_variant\x18\x01 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FeatureVariantH\x00\x12I\n\rlabel_variant\x18\x02 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.LabelVariantH\x00\x12K\n\x0esource_variant\x18\x03 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.SourceVariantH\x00\x12V\n\x14training_set_variant\x18\x04 \x01(\x0b\x32\x36.featureform.serving.metadata.proto.TrainingSetVariantH\x00\x12:\n\x05model\x18\x05 \x01(\x0b\x32).featureform.serving.metadata.proto.ModelH\x00\x12\x38\n\x04user\x18\x06 \x01(\x0b\x32(.featureform.serving.metadata.proto.UserH\x00\x12@\n\x08provider\x18\x07 \x01(\x0b\x32,.featureform.serving.metadata.proto.ProviderH\x00\x12<\n\x06\x65ntity\x18\x08 \x01(\x0b\x32*.featureform.serving.metadata.proto.EntityH\x00\x12G\n\x0c\x66\x65\x61ture_view\x18\t \x01(\x0b\x32/.featureform.serving.metadata.proto.FeatureViewH\x00\x42\x14\n\x12\x64\x65pendent_resource\"~\n#GetAllDownstreamDependenciesRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"Y\n\x0c\x43olumnSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0b\x32-.featureform.serving.metadata.proto.ValueType\"\x9f\x01\n\rFeatureColumn\x12\x45\n\x0b\x66\x65\x61ture_col\x18\x01 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.ColumnSchema\x12G\n\rtimestamp_col\x18\x02 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.ColumnSchema\"\x9f\x01\n\x0e\x46\x65\x61turesSchema\x12\x44\n\nentity_col\x18\x01 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.ColumnSchema\x12G\n\x0c\x66\x65\x61ture_cols\x18\x02 \x03(\x0b\x32\x31.featureform.serving.metadata.proto.FeatureColumn\"t\n\x0eOnlineLocation\x12\r\n\x05table\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x42\n\x06schema\x18\x03 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FeaturesSchema\"\xc0\x04\n\x0b\x46\x65\x61tureView\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x02 \x01(\t\x12\x41\n\x08\x66\x65\x61tures\x18\x03 \x03(\x0b\x32/.featureform.serving.metadata.proto.NameVariant\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12R\n\rtable_options\x18\x06 \x01(\x0b\x32;.featureform.serving.metadata.proto.FeatureViewTableOptions\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x42\n\x06status\x18\x08 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.ResourceStatus\x12\x14\n\x0ctask_id_list\x18\t \x03(\t\x12+\n\x07\x63reated\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0clast_updated\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x46\n\x10offline_location\x18\x0c \x01(\x0b\x32,.featureform.serving.metadata.proto.Location\x12\x45\n\x0fonline_location\x18\r \x01(\x0b\x32,.featureform.serving.metadata.proto.Location\"\x19\n\x17\x46\x65\x61tureViewTableOptions\"#\n!FeatureViewMaterializationOptions\"\xa0\x02\n\x12\x46\x65\x61tureViewRequest\x12\x45\n\x0c\x66\x65\x61ture_view\x18\x01 \x01(\x0b\x32/.featureform.serving.metadata.proto.FeatureView\x12\x66\n\x17materialization_options\x18\x02 \x01(\x0b\x32\x45.featureform.serving.metadata.proto.FeatureViewMaterializationOptions\x12\x1e\n\x16materialization_engine\x18\x03 \x01(\t\x12\'\n\x1fuse_super_admin_delete_override\x18\x04 \x01(\x08\x12\x12\n\nrequest_id\x18\x05 \x01(\t\"\xd3\x01\n FeatureViewLocationUpdateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x46\n\x10offline_location\x18\x02 \x01(\x0b\x32,.featureform.serving.metadata.proto.Location\x12\x45\n\x0fonline_location\x18\x03 \x01(\x0b\x32,.featureform.serving.metadata.proto.Location\x12\x12\n\nrequest_id\x18\x04 \x01(\t\"\xc4\x01\n\x1eGetUpstreamDependenciesRequest\x12\x43\n\x0bresource_id\x18\x01 \x01(\x0b\x32..featureform.serving.metadata.proto.ResourceID\x12I\n\x0f\x64\x65pendency_type\x18\x02 \x01(\x0e\x32\x30.featureform.serving.metadata.proto.ResourceType\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"\xb5\x05\n\x1fGetUpstreamDependenciesResponse\x12M\n\x0f\x66\x65\x61ture_variant\x18\x01 \x01(\x0b\x32\x32.featureform.serving.metadata.proto.FeatureVariantH\x00\x12I\n\rlabel_variant\x18\x02 \x01(\x0b\x32\x30.featureform.serving.metadata.proto.LabelVariantH\x00\x12K\n\x0esource_variant\x18\x03 \x01(\x0b\x32\x31.featureform.serving.metadata.proto.SourceVariantH\x00\x12V\n\x14training_set_variant\x18\x04 \x01(\x0b\x32\x36.featureform.serving.metadata.proto.TrainingSetVariantH\x00\x12:\n\x05model\x18\x05 \x01(\x0b\x32).featureform.serving.metadata.proto.ModelH\x00\x12\x38\n\x04user\x18\x06 \x01(\x0b\x32(.featureform.serving.metadata.proto.UserH\x00\x12@\n\x08provider\x18\x07 \x01(\x0b\x32,.featureform.serving.metadata.proto.ProviderH\x00\x12<\n\x06\x65ntity\x18\x08 \x01(\x0b\x32*.featureform.serving.metadata.proto.EntityH\x00\x12G\n\x0c\x66\x65\x61ture_view\x18\t \x01(\x0b\x32/.featureform.serving.metadata.proto.FeatureViewH\x00\x42\x14\n\x12\x64\x65pendent_resource*\xef\x01\n\x0cResourceType\x12\x0b\n\x07\x46\x45\x41TURE\x10\x00\x12\t\n\x05LABEL\x10\x01\x12\x10\n\x0cTRAINING_SET\x10\x02\x12\n\n\x06SOURCE\x10\x03\x12\x13\n\x0f\x46\x45\x41TURE_VARIANT\x10\x04\x12\x11\n\rLABEL_VARIANT\x10\x05\x12\x18\n\x14TRAINING_SET_VARIANT\x10\x06\x12\x12\n\x0eSOURCE_VARIANT\x10\x07\x12\x0c\n\x08PROVIDER\x10\x08\x12\n\n\x06\x45NTITY\x10\t\x12\t\n\x05MODEL\x10\n\x12\x08\n\x04USER\x10\x0b\x12\x10\n\x0c\x46\x45\x41TURE_VIEW\x10\x0c\x12\x12\n\x0eSTREAM_CHANNEL\x10\r*F\n\x0f\x43omputationMode\x12\x0f\n\x0bPRECOMPUTED\x10\x00\x12\x13\n\x0f\x43LIENT_COMPUTED\x10\x01\x12\r\n\tSTREAMING\x10\x02*\x82\x01\n\nScalarType\x12\x08\n\x04NULL\x10\x00\x12\x07\n\x03INT\x10\x01\x12\x0b\n\x07\x46LOAT32\x10\x02\x12\x0b\n\x07\x46LOAT64\x10\x03\x12\n\n\x06STRING\x10\x04\x12\x08\n\x04\x42OOL\x10\x05\x12\t\n\x05INT32\x10\x06\x12\t\n\x05INT64\x10\x07\x12\x0c\n\x08\x44\x41TETIME\x10\x08\x12\r\n\tTIMESTAMP\x10\t*%\n\x0bTableFormat\x12\x0b\n\x07ICEBERG\x10\x00\x12\t\n\x05\x44\x45LTA\x10\x01*\"\n\x0b\x43\x61talogType\x12\x08\n\x04GLUE\x10\x00\x12\t\n\x05UNITY\x10\x01*w\n\x0bRefreshMode\x12\x1c\n\x18REFRESH_MODE_UNSPECIFIED\x10\x00\x12\x15\n\x11REFRESH_MODE_AUTO\x10\x01\x12\x15\n\x11REFRESH_MODE_FULL\x10\x02\x12\x1c\n\x18REFRESH_MODE_INCREMENTAL\x10\x03*^\n\nInitialize\x12\x1a\n\x16INITIALIZE_UNSPECIFIED\x10\x00\x12\x18\n\x14INITIALIZE_ON_CREATE\x10\x01\x12\x1a\n\x16INITIALIZE_ON_SCHEDULE\x10\x02*\x8d\x01\n\x0fTrainingSetType\x12!\n\x1dTRAINING_SET_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19TRAINING_SET_TYPE_DYNAMIC\x10\x01\x12\x1c\n\x18TRAINING_SET_TYPE_STATIC\x10\x02\x12\x1a\n\x16TRAINING_SET_TYPE_VIEW\x10\x03\x32\xd4-\n\x08Metadata\x12j\n\rGetAuthConfig\x12).featureform.serving.metadata.proto.Empty\x1a..featureform.serving.metadata.proto.AuthConfig\x12h\n\nCreateUser\x12/.featureform.serving.metadata.proto.UserRequest\x1a).featureform.serving.metadata.proto.Empty\x12p\n\x0e\x43reateProvider\x12\x33.featureform.serving.metadata.proto.ProviderRequest\x1a).featureform.serving.metadata.proto.Empty\x12z\n\x13\x43reateSourceVariant\x12\x38.featureform.serving.metadata.proto.SourceVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12l\n\x0c\x43reateEntity\x12\x31.featureform.serving.metadata.proto.EntityRequest\x1a).featureform.serving.metadata.proto.Empty\x12|\n\x14\x43reateFeatureVariant\x12\x39.featureform.serving.metadata.proto.FeatureVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12x\n\x12\x43reateLabelVariant\x12\x37.featureform.serving.metadata.proto.LabelVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12\x84\x01\n\x18\x43reateTrainingSetVariant\x12=.featureform.serving.metadata.proto.TrainingSetVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12j\n\x0b\x43reateModel\x12\x30.featureform.serving.metadata.proto.ModelRequest\x1a).featureform.serving.metadata.proto.Empty\x12z\n\x13\x43reateStreamChannel\x12\x38.featureform.serving.metadata.proto.StreamChannelRequest\x1a).featureform.serving.metadata.proto.Empty\x12}\n\x15RequestScheduleChange\x12\x39.featureform.serving.metadata.proto.ScheduleChangeRequest\x1a).featureform.serving.metadata.proto.Empty\x12{\n\x16MaterializeFeatureView\x12\x36.featureform.serving.metadata.proto.FeatureViewRequest\x1a).featureform.serving.metadata.proto.Empty\x12i\n\x08GetUsers\x12/.featureform.serving.metadata.proto.NameRequest\x1a(.featureform.serving.metadata.proto.User(\x01\x30\x01\x12o\n\x0bGetFeatures\x12/.featureform.serving.metadata.proto.NameRequest\x1a+.featureform.serving.metadata.proto.Feature(\x01\x30\x01\x12\x84\x01\n\x12GetFeatureVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x32.featureform.serving.metadata.proto.FeatureVariant(\x01\x30\x01\x12k\n\tGetLabels\x12/.featureform.serving.metadata.proto.NameRequest\x1a).featureform.serving.metadata.proto.Label(\x01\x30\x01\x12\x80\x01\n\x10GetLabelVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x30.featureform.serving.metadata.proto.LabelVariant(\x01\x30\x01\x12w\n\x0fGetTrainingSets\x12/.featureform.serving.metadata.proto.NameRequest\x1a/.featureform.serving.metadata.proto.TrainingSet(\x01\x30\x01\x12\x8c\x01\n\x16GetTrainingSetVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x36.featureform.serving.metadata.proto.TrainingSetVariant(\x01\x30\x01\x12m\n\nGetSources\x12/.featureform.serving.metadata.proto.NameRequest\x1a*.featureform.serving.metadata.proto.Source(\x01\x30\x01\x12\x82\x01\n\x11GetSourceVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x31.featureform.serving.metadata.proto.SourceVariant(\x01\x30\x01\x12q\n\x0cGetProviders\x12/.featureform.serving.metadata.proto.NameRequest\x1a,.featureform.serving.metadata.proto.Provider(\x01\x30\x01\x12n\n\x0bGetEntities\x12/.featureform.serving.metadata.proto.NameRequest\x1a*.featureform.serving.metadata.proto.Entity(\x01\x30\x01\x12k\n\tGetModels\x12/.featureform.serving.metadata.proto.NameRequest\x1a).featureform.serving.metadata.proto.Model(\x01\x30\x01\x12{\n\x11GetStreamChannels\x12/.featureform.serving.metadata.proto.NameRequest\x1a\x31.featureform.serving.metadata.proto.StreamChannel(\x01\x30\x01\x12\xac\x01\n\x19GetDownstreamDependencies\x12\x44.featureform.serving.metadata.proto.GetDownstreamDependenciesRequest\x1a\x45.featureform.serving.metadata.proto.GetDownstreamDependenciesResponse(\x01\x30\x01\x12\x9b\x01\n\x1cGetAllDownstreamDependencies\x12G.featureform.serving.metadata.proto.GetAllDownstreamDependenciesRequest\x1a..featureform.serving.metadata.proto.ResourceID(\x01\x30\x01\x12w\n\x0fGetFeatureViews\x12/.featureform.serving.metadata.proto.NameRequest\x1a/.featureform.serving.metadata.proto.FeatureView(\x01\x30\x01\x12\xa6\x01\n\x17GetUpstreamDependencies\x12\x42.featureform.serving.metadata.proto.GetUpstreamDependenciesRequest\x1a\x43.featureform.serving.metadata.proto.GetUpstreamDependenciesResponse(\x01\x30\x01\x12\x8a\x01\n\x0fMarkForDeletion\x12:.featureform.serving.metadata.proto.MarkForDeletionRequest\x1a;.featureform.serving.metadata.proto.MarkForDeletionResponse\x12\x8d\x01\n\x10\x46inalizeDeletion\x12;.featureform.serving.metadata.proto.FinalizeDeletionRequest\x1a<.featureform.serving.metadata.proto.FinalizeDeletionResponse\x12\xb1\x01\n\x1cGetStagedForDeletionResource\x12G.featureform.serving.metadata.proto.GetStagedForDeletionResourceRequest\x1aH.featureform.serving.metadata.proto.GetStagedForDeletionResourceResponse\x12\x84\x01\n\rPruneResource\x12\x38.featureform.serving.metadata.proto.PruneResourceRequest\x1a\x39.featureform.serving.metadata.proto.PruneResourceResponse\x12~\n\rGetEquivalent\x12\x38.featureform.serving.metadata.proto.GetEquivalentRequest\x1a\x33.featureform.serving.metadata.proto.ResourceVariant\x12`\n\x03Run\x12..featureform.serving.metadata.proto.RunRequest\x1a).featureform.serving.metadata.proto.Empty\x12n\n\x0cListFeatures\x12/.featureform.serving.metadata.proto.ListRequest\x1a+.featureform.serving.metadata.proto.Feature0\x01\x12j\n\nListLabels\x12/.featureform.serving.metadata.proto.ListRequest\x1a).featureform.serving.metadata.proto.Label0\x01\x12v\n\x10ListTrainingSets\x12/.featureform.serving.metadata.proto.ListRequest\x1a/.featureform.serving.metadata.proto.TrainingSet0\x01\x12l\n\x0bListSources\x12/.featureform.serving.metadata.proto.ListRequest\x1a*.featureform.serving.metadata.proto.Source0\x01\x12h\n\tListUsers\x12/.featureform.serving.metadata.proto.ListRequest\x1a(.featureform.serving.metadata.proto.User0\x01\x12p\n\rListProviders\x12/.featureform.serving.metadata.proto.ListRequest\x1a,.featureform.serving.metadata.proto.Provider0\x01\x12m\n\x0cListEntities\x12/.featureform.serving.metadata.proto.ListRequest\x1a*.featureform.serving.metadata.proto.Entity0\x01\x12j\n\nListModels\x12/.featureform.serving.metadata.proto.ListRequest\x1a).featureform.serving.metadata.proto.Model0\x01\x12v\n\x10ListFeatureViews\x12/.featureform.serving.metadata.proto.ListRequest\x1a/.featureform.serving.metadata.proto.FeatureView0\x01\x12z\n\x12ListStreamChannels\x12/.featureform.serving.metadata.proto.ListRequest\x1a\x31.featureform.serving.metadata.proto.StreamChannel0\x01\x12t\n\x11SetResourceStatus\x12\x34.featureform.serving.metadata.proto.SetStatusRequest\x1a).featureform.serving.metadata.proto.Empty\x12\x8a\x01\n\x17SetFeatureViewLocations\x12\x44.featureform.serving.metadata.proto.FeatureViewLocationUpdateRequest\x1a).featureform.serving.metadata.proto.Empty2\xbe-\n\x03\x41pi\x12j\n\rGetAuthConfig\x12).featureform.serving.metadata.proto.Empty\x1a..featureform.serving.metadata.proto.AuthConfig\x12h\n\nCreateUser\x12/.featureform.serving.metadata.proto.UserRequest\x1a).featureform.serving.metadata.proto.Empty\x12p\n\x0e\x43reateProvider\x12\x33.featureform.serving.metadata.proto.ProviderRequest\x1a).featureform.serving.metadata.proto.Empty\x12z\n\x13\x43reateSourceVariant\x12\x38.featureform.serving.metadata.proto.SourceVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12l\n\x0c\x43reateEntity\x12\x31.featureform.serving.metadata.proto.EntityRequest\x1a).featureform.serving.metadata.proto.Empty\x12|\n\x14\x43reateFeatureVariant\x12\x39.featureform.serving.metadata.proto.FeatureVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12x\n\x12\x43reateLabelVariant\x12\x37.featureform.serving.metadata.proto.LabelVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12\x84\x01\n\x18\x43reateTrainingSetVariant\x12=.featureform.serving.metadata.proto.TrainingSetVariantRequest\x1a).featureform.serving.metadata.proto.Empty\x12j\n\x0b\x43reateModel\x12\x30.featureform.serving.metadata.proto.ModelRequest\x1a).featureform.serving.metadata.proto.Empty\x12z\n\x13\x43reateStreamChannel\x12\x38.featureform.serving.metadata.proto.StreamChannelRequest\x1a).featureform.serving.metadata.proto.Empty\x12}\n\x15RequestScheduleChange\x12\x39.featureform.serving.metadata.proto.ScheduleChangeRequest\x1a).featureform.serving.metadata.proto.Empty\x12{\n\x16MaterializeFeatureView\x12\x36.featureform.serving.metadata.proto.FeatureViewRequest\x1a).featureform.serving.metadata.proto.Empty\x12i\n\x08GetUsers\x12/.featureform.serving.metadata.proto.NameRequest\x1a(.featureform.serving.metadata.proto.User(\x01\x30\x01\x12o\n\x0bGetFeatures\x12/.featureform.serving.metadata.proto.NameRequest\x1a+.featureform.serving.metadata.proto.Feature(\x01\x30\x01\x12\x84\x01\n\x12GetFeatureVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x32.featureform.serving.metadata.proto.FeatureVariant(\x01\x30\x01\x12k\n\tGetLabels\x12/.featureform.serving.metadata.proto.NameRequest\x1a).featureform.serving.metadata.proto.Label(\x01\x30\x01\x12\x80\x01\n\x10GetLabelVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x30.featureform.serving.metadata.proto.LabelVariant(\x01\x30\x01\x12w\n\x0fGetTrainingSets\x12/.featureform.serving.metadata.proto.NameRequest\x1a/.featureform.serving.metadata.proto.TrainingSet(\x01\x30\x01\x12\x8c\x01\n\x16GetTrainingSetVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x36.featureform.serving.metadata.proto.TrainingSetVariant(\x01\x30\x01\x12m\n\nGetSources\x12/.featureform.serving.metadata.proto.NameRequest\x1a*.featureform.serving.metadata.proto.Source(\x01\x30\x01\x12\x82\x01\n\x11GetSourceVariants\x12\x36.featureform.serving.metadata.proto.NameVariantRequest\x1a\x31.featureform.serving.metadata.proto.SourceVariant(\x01\x30\x01\x12q\n\x0cGetProviders\x12/.featureform.serving.metadata.proto.NameRequest\x1a,.featureform.serving.metadata.proto.Provider(\x01\x30\x01\x12n\n\x0bGetEntities\x12/.featureform.serving.metadata.proto.NameRequest\x1a*.featureform.serving.metadata.proto.Entity(\x01\x30\x01\x12k\n\tGetModels\x12/.featureform.serving.metadata.proto.NameRequest\x1a).featureform.serving.metadata.proto.Model(\x01\x30\x01\x12{\n\x11GetStreamChannels\x12/.featureform.serving.metadata.proto.NameRequest\x1a\x31.featureform.serving.metadata.proto.StreamChannel(\x01\x30\x01\x12\xac\x01\n\x19GetDownstreamDependencies\x12\x44.featureform.serving.metadata.proto.GetDownstreamDependenciesRequest\x1a\x45.featureform.serving.metadata.proto.GetDownstreamDependenciesResponse(\x01\x30\x01\x12\x9b\x01\n\x1cGetAllDownstreamDependencies\x12G.featureform.serving.metadata.proto.GetAllDownstreamDependenciesRequest\x1a..featureform.serving.metadata.proto.ResourceID(\x01\x30\x01\x12w\n\x0fGetFeatureViews\x12/.featureform.serving.metadata.proto.NameRequest\x1a/.featureform.serving.metadata.proto.FeatureView(\x01\x30\x01\x12\xa6\x01\n\x17GetUpstreamDependencies\x12\x42.featureform.serving.metadata.proto.GetUpstreamDependenciesRequest\x1a\x43.featureform.serving.metadata.proto.GetUpstreamDependenciesResponse(\x01\x30\x01\x12\x8a\x01\n\x0fMarkForDeletion\x12:.featureform.serving.metadata.proto.MarkForDeletionRequest\x1a;.featureform.serving.metadata.proto.MarkForDeletionResponse\x12\x8d\x01\n\x10\x46inalizeDeletion\x12;.featureform.serving.metadata.proto.FinalizeDeletionRequest\x1a<.featureform.serving.metadata.proto.FinalizeDeletionResponse\x12\xb1\x01\n\x1cGetStagedForDeletionResource\x12G.featureform.serving.metadata.proto.GetStagedForDeletionResourceRequest\x1aH.featureform.serving.metadata.proto.GetStagedForDeletionResourceResponse\x12\x84\x01\n\rPruneResource\x12\x38.featureform.serving.metadata.proto.PruneResourceRequest\x1a\x39.featureform.serving.metadata.proto.PruneResourceResponse\x12~\n\rGetEquivalent\x12\x38.featureform.serving.metadata.proto.GetEquivalentRequest\x1a\x33.featureform.serving.metadata.proto.ResourceVariant\x12`\n\x03Run\x12..featureform.serving.metadata.proto.RunRequest\x1a).featureform.serving.metadata.proto.Empty\x12n\n\x0cListFeatures\x12/.featureform.serving.metadata.proto.ListRequest\x1a+.featureform.serving.metadata.proto.Feature0\x01\x12j\n\nListLabels\x12/.featureform.serving.metadata.proto.ListRequest\x1a).featureform.serving.metadata.proto.Label0\x01\x12v\n\x10ListTrainingSets\x12/.featureform.serving.metadata.proto.ListRequest\x1a/.featureform.serving.metadata.proto.TrainingSet0\x01\x12l\n\x0bListSources\x12/.featureform.serving.metadata.proto.ListRequest\x1a*.featureform.serving.metadata.proto.Source0\x01\x12h\n\tListUsers\x12/.featureform.serving.metadata.proto.ListRequest\x1a(.featureform.serving.metadata.proto.User0\x01\x12p\n\rListProviders\x12/.featureform.serving.metadata.proto.ListRequest\x1a,.featureform.serving.metadata.proto.Provider0\x01\x12m\n\x0cListEntities\x12/.featureform.serving.metadata.proto.ListRequest\x1a*.featureform.serving.metadata.proto.Entity0\x01\x12j\n\nListModels\x12/.featureform.serving.metadata.proto.ListRequest\x1a).featureform.serving.metadata.proto.Model0\x01\x12y\n\rWriteFeatures\x12;.featureform.serving.metadata.proto.StreamingFeatureVariant\x1a).featureform.serving.metadata.proto.Empty(\x01\x12u\n\x0bWriteLabels\x12\x39.featureform.serving.metadata.proto.StreamingLabelVariant\x1a).featureform.serving.metadata.proto.Empty(\x01\x12v\n\x10ListFeatureViews\x12/.featureform.serving.metadata.proto.ListRequest\x1a/.featureform.serving.metadata.proto.FeatureView0\x01\x12z\n\x12ListStreamChannels\x12/.featureform.serving.metadata.proto.ListRequest\x1a\x31.featureform.serving.metadata.proto.StreamChannel0\x01\x42\'Z%github.com/featureform/metadata/protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'featureform.proto.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z%github.com/featureform/metadata/proto'
  _globals['_FEATUREVARIANT'].fields_by_name['task_id']._options = None
  _globals['_FEATUREVARIANT'].fields_by_name['task_id']._serialized_options = b'\030\001'
  _globals['_FEATUREVARIANT'].fields_by_name['is_deleted']._options = None
  _globals['_FEATUREVARIANT'].fields_by_name['is_deleted']._serialized_options = b'\030\001'
  _globals['_FEATUREVARIANT'].fields_by_name['deleted']._options = None
  _globals['_FEATUREVARIANT'].fields_by_name['deleted']._serialized_options = b'\030\001'
  _globals['_LABELVARIANT'].fields_by_name['task_id']._options = None
  _globals['_LABELVARIANT'].fields_by_name['task_id']._serialized_options = b'\030\001'
  _globals['_LABELVARIANT'].fields_by_name['is_deleted']._options = None
  _globals['_LABELVARIANT'].fields_by_name['is_deleted']._serialized_options = b'\030\001'
  _globals['_LABELVARIANT'].fields_by_name['deleted']._options = None
  _globals['_LABELVARIANT'].fields_by_name['deleted']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['is_deleted']._options = None
  _globals['_PROVIDER'].fields_by_name['is_deleted']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['deleted']._options = None
  _globals['_PROVIDER'].fields_by_name['deleted']._serialized_options = b'\030\001'
  _globals['_TRAININGSETVARIANT'].fields_by_name['task_id']._options = None
  _globals['_TRAININGSETVARIANT'].fields_by_name['task_id']._serialized_options = b'\030\001'
  _globals['_TRAININGSETVARIANT'].fields_by_name['is_deleted']._options = None
  _globals['_TRAININGSETVARIANT'].fields_by_name['is_deleted']._serialized_options = b'\030\001'
  _globals['_TRAININGSETVARIANT'].fields_by_name['deleted']._options = None
  _globals['_TRAININGSETVARIANT'].fields_by_name['deleted']._serialized_options = b'\030\001'
  _globals['_SOURCEVARIANT'].fields_by_name['task_id']._options = None
  _globals['_SOURCEVARIANT'].fields_by_name['task_id']._serialized_options = b'\030\001'
  _globals['_SOURCEVARIANT'].fields_by_name['is_deleted']._options = None
  _globals['_SOURCEVARIANT'].fields_by_name['is_deleted']._serialized_options = b'\030\001'
  _globals['_SOURCEVARIANT'].fields_by_name['deleted']._options = None
  _globals['_SOURCEVARIANT'].fields_by_name['deleted']._serialized_options = b'\030\001'
  _globals['_LOCATION'].fields_by_name['kafka']._options = None
  _globals['_LOCATION'].fields_by_name['kafka']._serialized_options = b'\030\001'
  _globals['_TRANSFORMATION'].fields_by_name['kafka']._options = None
  _globals['_TRANSFORMATION'].fields_by_name['kafka']._serialized_options = b'\030\001'
  _globals['_PRIMARYDATA'].fields_by_name['kafka']._options = None
  _globals['_PRIMARYDATA'].fields_by_name['kafka']._serialized_options = b'\030\001'
  _globals['_PROPERTIES_PROPERTYENTRY']._options = None
  _globals['_PROPERTIES_PROPERTYENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCETYPE']._serialized_start=19889
  _globals['_RESOURCETYPE']._serialized_end=20128
  _globals['_COMPUTATIONMODE']._serialized_start=20130
  _globals['_COMPUTATIONMODE']._serialized_end=20200
  _globals['_SCALARTYPE']._serialized_start=20203
  _globals['_SCALARTYPE']._serialized_end=20333
  _globals['_TABLEFORMAT']._serialized_start=20335
  _globals['_TABLEFORMAT']._serialized_end=20372
  _globals['_CATALOGTYPE']._serialized_start=20374
  _globals['_CATALOGTYPE']._serialized_end=20408
  _globals['_REFRESHMODE']._serialized_start=20410
  _globals['_REFRESHMODE']._serialized_end=20529
  _globals['_INITIALIZE']._serialized_start=20531
  _globals['_INITIALIZE']._serialized_end=20625
  _globals['_TRAININGSETTYPE']._serialized_start=20628
  _globals['_TRAININGSETTYPE']._serialized_end=20769
  _globals['_OKTAAUTHCONFIG']._serialized_start=164
  _globals['_OKTAAUTHCONFIG']._serialized_end=271
  _globals['_PASSTHROUGHAUTHCONFIG']._serialized_start=273
  _globals['_PASSTHROUGHAUTHCONFIG']._serialized_end=296
  _globals['_CIDRAUTHCONFIG']._serialized_start=298
  _globals['_CIDRAUTHCONFIG']._serialized_end=314
  _globals['_AUTHCONFIG']._serialized_start=317
  _globals['_AUTHCONFIG']._serialized_end=558
  _globals['_NAME']._serialized_start=560
  _globals['_NAME']._serialized_end=580
  _globals['_NAMEREQUEST']._serialized_start=582
  _globals['_NAMEREQUEST']._serialized_end=671
  _globals['_ERRORSTATUS']._serialized_start=673
  _globals['_ERRORSTATUS']._serialized_end=756
  _globals['_RESOURCESTATUS']._serialized_start=759
  _globals['_RESOURCESTATUS']._serialized_end=1046
  _globals['_RESOURCESTATUS_STATUS']._serialized_start=946
  _globals['_RESOURCESTATUS_STATUS']._serialized_end=1046
  _globals['_RESOURCEID']._serialized_start=1049
  _globals['_RESOURCEID']._serialized_end=1201
  _globals['_SETSTATUSREQUEST']._serialized_start=1204
  _globals['_SETSTATUSREQUEST']._serialized_end=1359
  _globals['_SCHEDULECHANGEREQUEST']._serialized_start=1361
  _globals['_SCHEDULECHANGEREQUEST']._serialized_end=1471
  _globals['_NAMEVARIANT']._serialized_start=1473
  _globals['_NAMEVARIANT']._serialized_end=1517
  _globals['_NAMEVARIANTREQUEST']._serialized_start=1519
  _globals['_NAMEVARIANTREQUEST']._serialized_end=1630
  _globals['_EMPTY']._serialized_start=1632
  _globals['_EMPTY']._serialized_end=1639
  _globals['_LISTREQUEST']._serialized_start=1641
  _globals['_LISTREQUEST']._serialized_end=1674
  _globals['_FEATURE']._serialized_start=1677
  _globals['_FEATURE']._serialized_end=1811
  _globals['_COLUMNS']._serialized_start=1813
  _globals['_COLUMNS']._serialized_end=1865
  _globals['_PYTHONFUNCTION']._serialized_start=1867
  _globals['_PYTHONFUNCTION']._serialized_end=1898
  _globals['_STREAM']._serialized_start=1900
  _globals['_STREAM']._serialized_end=1934
  _globals['_RESOURCEVARIANT']._serialized_start=1937
  _globals['_RESOURCEVARIANT']._serialized_end=2358
  _globals['_GETEQUIVALENTREQUEST']._serialized_start=2360
  _globals['_GETEQUIVALENTREQUEST']._serialized_end=2472
  _globals['_RUNREQUEST']._serialized_start=2474
  _globals['_RUNREQUEST']._serialized_end=2577
  _globals['_FEATUREVARIANT']._serialized_start=2580
  _globals['_FEATUREVARIANT']._serialized_end=3908
  _globals['_FEATUREVARIANTREQUEST']._serialized_start=3910
  _globals['_FEATUREVARIANTREQUEST']._serialized_end=4030
  _globals['_VALUETYPE']._serialized_start=4033
  _globals['_VALUETYPE']._serialized_end=4184
  _globals['_VECTORTYPE']._serialized_start=4186
  _globals['_VECTORTYPE']._serialized_end=4303
  _globals['_FEATUREPARAMETERS']._serialized_start=4306
  _globals['_FEATUREPARAMETERS']._serialized_end=4513
  _globals['_PRECOMPUTEDFEATUREPARAMETERS']._serialized_start=4515
  _globals['_PRECOMPUTEDFEATUREPARAMETERS']._serialized_end=4545
  _globals['_ONDEMANDFEATUREPARAMETERS']._serialized_start=4547
  _globals['_ONDEMANDFEATUREPARAMETERS']._serialized_end=4594
  _globals['_FEATURELAG']._serialized_start=4596
  _globals['_FEATURELAG']._serialized_end=4696
  _globals['_LABEL']._serialized_start=4699
  _globals['_LABEL']._serialized_end=4831
  _globals['_LABELVARIANT']._serialized_start=4834
  _globals['_LABELVARIANT']._serialized_end=5812
  _globals['_ENTITYMAPPINGS']._serialized_start=5815
  _globals['_ENTITYMAPPINGS']._serialized_end=5948
  _globals['_ENTITYMAPPING']._serialized_start=5950
  _globals['_ENTITYMAPPING']._serialized_end=6002
  _globals['_LABELVARIANTREQUEST']._serialized_start=6004
  _globals['_LABELVARIANTREQUEST']._serialized_end=6118
  _globals['_PROVIDER']._serialized_start=6121
  _globals['_PROVIDER']._serialized_end=6773
  _globals['_PROVIDERREQUEST']._serialized_start=6775
  _globals['_PROVIDERREQUEST']._serialized_end=6876
  _globals['_TRAININGSET']._serialized_start=6879
  _globals['_TRAININGSET']._serialized_end=7017
  _globals['_TRAININGSETVARIANT']._serialized_start=7020
  _globals['_TRAININGSETVARIANT']._serialized_end=7910
  _globals['_TRAININGSETVARIANTREQUEST']._serialized_start=7913
  _globals['_TRAININGSETVARIANTREQUEST']._serialized_end=8046
  _globals['_ENTITY']._serialized_start=8049
  _globals['_ENTITY']._serialized_end=8510
  _globals['_ENTITYREQUEST']._serialized_start=8512
  _globals['_ENTITYREQUEST']._serialized_end=8607
  _globals['_MODEL']._serialized_start=8610
  _globals['_MODEL']._serialized_end=8979
  _globals['_MODELREQUEST']._serialized_start=8981
  _globals['_MODELREQUEST']._serialized_end=9073
  _globals['_STREAMCHANNEL']._serialized_start=9076
  _globals['_STREAMCHANNEL']._serialized_end=9344
  _globals['_STREAMCHANNELREQUEST']._serialized_start=9346
  _globals['_STREAMCHANNELREQUEST']._serialized_end=9463
  _globals['_USER']._serialized_start=9466
  _globals['_USER']._serialized_end=9970
  _globals['_USERREQUEST']._serialized_start=9972
  _globals['_USERREQUEST']._serialized_end=10061
  _globals['_SOURCE']._serialized_start=10064
  _globals['_SOURCE']._serialized_end=10197
  _globals['_SOURCEVARIANT']._serialized_start=10200
  _globals['_SOURCEVARIANT']._serialized_end=11156
  _globals['_SOURCEVARIANTREQUEST']._serialized_start=11158
  _globals['_SOURCEVARIANTREQUEST']._serialized_end=11275
  _globals['_SPARKPARAM']._serialized_start=11277
  _globals['_SPARKPARAM']._serialized_end=11317
  _globals['_WRITEOPTION']._serialized_start=11319
  _globals['_WRITEOPTION']._serialized_end=11360
  _globals['_TABLEPROPERTY']._serialized_start=11362
  _globals['_TABLEPROPERTY']._serialized_end=11405
  _globals['_SPARKFLAGS']._serialized_start=11408
  _globals['_SPARKFLAGS']._serialized_end=11639
  _globals['_LOCATION']._serialized_start=11642
  _globals['_LOCATION']._serialized_end=12080
  _globals['_TRANSFORMATION']._serialized_start=12083
  _globals['_TRANSFORMATION']._serialized_end=12954
  _globals['_HASHPARTITION']._serialized_start=12956
  _globals['_HASHPARTITION']._serialized_end=13004
  _globals['_DAILYPARTITION']._serialized_start=13006
  _globals['_DAILYPARTITION']._serialized_end=13038
  _globals['_KUBERNETESRESOURCESPECS']._serialized_start=13040
  _globals['_KUBERNETESRESOURCESPECS']._serialized_end=13151
  _globals['_KUBERNETESARGS']._serialized_start=13153
  _globals['_KUBERNETESARGS']._serialized_end=13267
  _globals['_SQLTRANSFORMATION']._serialized_start=13270
  _globals['_SQLTRANSFORMATION']._serialized_end=13664
  _globals['_DFTRANSFORMATION']._serialized_start=13667
  _globals['_DFTRANSFORMATION']._serialized_end=14012
  _globals['_PRIMARYDATA']._serialized_start=14015
  _globals['_PRIMARYDATA']._serialized_end=14412
  _globals['_SQLTABLE']._serialized_start=14414
  _globals['_SQLTABLE']._serialized_end=14472
  _globals['_FILESTORETABLE']._serialized_start=14474
  _globals['_FILESTORETABLE']._serialized_end=14504
  _globals['_KAFKA']._serialized_start=14506
  _globals['_KAFKA']._serialized_end=14528
  _globals['_CATALOGTABLE']._serialized_start=14531
  _globals['_CATALOGTABLE']._serialized_end=14687
  _globals['_TAGS']._serialized_start=14689
  _globals['_TAGS']._serialized_end=14708
  _globals['_PROPERTY']._serialized_start=14710
  _globals['_PROPERTY']._serialized_end=14753
  _globals['_PROPERTIES']._serialized_start=14756
  _globals['_PROPERTIES']._serialized_end=14943
  _globals['_PROPERTIES_PROPERTYENTRY']._serialized_start=14850
  _globals['_PROPERTIES_PROPERTYENTRY']._serialized_end=14943
  _globals['_STREAMINGFEATUREVARIANT']._serialized_start=14945
  _globals['_STREAMINGFEATUREVARIANT']._serialized_end=15072
  _globals['_STREAMINGLABELVARIANT']._serialized_start=15074
  _globals['_STREAMINGLABELVARIANT']._serialized_end=15199
  _globals['_RESOURCESNOWFLAKECONFIG']._serialized_start=15202
  _globals['_RESOURCESNOWFLAKECONFIG']._serialized_end=15341
  _globals['_SNOWFLAKEDYNAMICTABLECONFIG']._serialized_start=15344
  _globals['_SNOWFLAKEDYNAMICTABLECONFIG']._serialized_end=15532
  _globals['_MARKFORDELETIONREQUEST']._serialized_start=15534
  _globals['_MARKFORDELETIONREQUEST']._serialized_end=15627
  _globals['_MARKFORDELETIONRESPONSE']._serialized_start=15629
  _globals['_MARKFORDELETIONRESPONSE']._serialized_end=15654
  _globals['_FINALIZEDELETIONREQUEST']._serialized_start=15656
  _globals['_FINALIZEDELETIONREQUEST']._serialized_end=15750
  _globals['_FINALIZEDELETIONRESPONSE']._serialized_start=15752
  _globals['_FINALIZEDELETIONRESPONSE']._serialized_end=15778
  _globals['_GETSTAGEDFORDELETIONRESOURCEREQUEST']._serialized_start=15780
  _globals['_GETSTAGEDFORDELETIONRESOURCEREQUEST']._serialized_end=15886
  _globals['_GETSTAGEDFORDELETIONRESOURCERESPONSE']._serialized_start=15888
  _globals['_GETSTAGEDFORDELETIONRESOURCERESPONSE']._serialized_end=16005
  _globals['_PRUNERESOURCEREQUEST']._serialized_start=16007
  _globals['_PRUNERESOURCEREQUEST']._serialized_end=16098
  _globals['_PRUNERESOURCERESPONSE']._serialized_start=16101
  _globals['_PRUNERESOURCERESPONSE']._serialized_end=16283
  _globals['_GETDOWNSTREAMDEPENDENCIESREQUEST']._serialized_start=16286
  _globals['_GETDOWNSTREAMDEPENDENCIESREQUEST']._serialized_end=16484
  _globals['_GETDOWNSTREAMDEPENDENCIESRESPONSE']._serialized_start=16487
  _globals['_GETDOWNSTREAMDEPENDENCIESRESPONSE']._serialized_end=17182
  _globals['_GETALLDOWNSTREAMDEPENDENCIESREQUEST']._serialized_start=17184
  _globals['_GETALLDOWNSTREAMDEPENDENCIESREQUEST']._serialized_end=17310
  _globals['_COLUMNSCHEMA']._serialized_start=17312
  _globals['_COLUMNSCHEMA']._serialized_end=17401
  _globals['_FEATURECOLUMN']._serialized_start=17404
  _globals['_FEATURECOLUMN']._serialized_end=17563
  _globals['_FEATURESSCHEMA']._serialized_start=17566
  _globals['_FEATURESSCHEMA']._serialized_end=17725
  _globals['_ONLINELOCATION']._serialized_start=17727
  _globals['_ONLINELOCATION']._serialized_end=17843
  _globals['_FEATUREVIEW']._serialized_start=17846
  _globals['_FEATUREVIEW']._serialized_end=18422
  _globals['_FEATUREVIEWTABLEOPTIONS']._serialized_start=18424
  _globals['_FEATUREVIEWTABLEOPTIONS']._serialized_end=18449
  _globals['_FEATUREVIEWMATERIALIZATIONOPTIONS']._serialized_start=18451
  _globals['_FEATUREVIEWMATERIALIZATIONOPTIONS']._serialized_end=18486
  _globals['_FEATUREVIEWREQUEST']._serialized_start=18489
  _globals['_FEATUREVIEWREQUEST']._serialized_end=18777
  _globals['_FEATUREVIEWLOCATIONUPDATEREQUEST']._serialized_start=18780
  _globals['_FEATUREVIEWLOCATIONUPDATEREQUEST']._serialized_end=18991
  _globals['_GETUPSTREAMDEPENDENCIESREQUEST']._serialized_start=18994
  _globals['_GETUPSTREAMDEPENDENCIESREQUEST']._serialized_end=19190
  _globals['_GETUPSTREAMDEPENDENCIESRESPONSE']._serialized_start=19193
  _globals['_GETUPSTREAMDEPENDENCIESRESPONSE']._serialized_end=19886
  _globals['_METADATA']._serialized_start=20772
  _globals['_METADATA']._serialized_end=26616
  _globals['_API']._serialized_start=26619
  _globals['_API']._serialized_end=32441
# @@protoc_insertion_point(module_scope)
